About
=====

Why yet another BCI framework?
------------------------------

We needed something that:

* fits well within the Python datascience and machine learning ecosystem
* has a permissive license, allowing commercial applications
* works both offline and online
* enables quick prototyping
* is developer-friendly
* is not only about EEG data or even about the brain, and that can works with any time series

We were not able to find a framework that satisfied all of our requirements, so we built it.

The team
--------

Timeflux is primarily developed by `Pierre Clisson <https://clisson.net>`_ and `Raphaëlle Bertrand-Lalo <https://www.linkedin.com/in/raphaëlle-bertrand-lalo-185679b9/>`_, with the support of awesome contributors.

Citing
------

The `introduction paper <https://timeflux.io/assets/pdf/Timeflux_GBCIC2019.pdf>`_ has been be published in the Proceedings of the 2019 Graz BCI Conference.